use bevy::prelude::*;

use crate::{
    AppState,
    cleanup::{self, despawn},
};

mod camera;
mod debug;
mod player;
mod scene;

pub use player::PlayerMode;

/// Gameplay system set. All functions in this control the gameplay (duh).
#[derive(SystemSet, Debug, Clone, PartialEq, Eq, Hash)]
struct GameplaySet;

pub fn plugin(app: &mut App) {
    app.add_systems(
        OnExit(AppState::Ingame),
        despawn::<cleanup::Scene>.in_set(GameplaySet),
    )
    .add_plugins((camera::plugin, scene::plugin, debug::plugin))
    .add_plugins(player::plugin);
    app.configure_sets(Update, GameplaySet.run_if(in_state(AppState::Ingame)));
}
