#![feature(iter_collect_into)]
use bevy::prelude::*;
use bevy_rapier3d::plugin::{NoUserData, RapierPhysicsPlugin};
use bevy_skein::SkeinPlugin;
use bevy_ui_text_input::TextInputPlugin;
use clap::ValueEnum;

mod camera;
mod cleanup;
mod debug;
mod game;
mod menus;

#[derive(States, Default, Debug, Clone, PartialEq, Eq, Hash, Reflect, ValueEnum)]
#[allow(unused)]
enum AppState {
    #[default]
    Menus,
    Ingame,
    PostGame,
}

fn main() {
    App::new()
        .add_systems(Startup, camera::setup)
        .add_plugins((
            DefaultPlugins,
            TextInputPlugin,
            RapierPhysicsPlugin::<NoUserData>::default(),
            SkeinPlugin::default(),
        ))
        .add_plugins((game::plugin, menus::plugin, debug::plugin))
        .init_state::<AppState>()
        .register_type::<AppState>()
        .run();
}
